Cosmetics.
[paraslash.git] / sched.c
diff --git a/sched.c b/sched.c
index 144eaf6e21a670d1243a07d00689cf6a3fbd1900..ba43b10cff143960d3741fb6c0f7238b351de865 100644 (file)
--- a/sched.c
+++ b/sched.c
@@ -6,7 +6,10 @@
 
 /** \file sched.c paraslash's scheduling functions */
 
 
 /** \file sched.c paraslash's scheduling functions */
 
+#include <dirent.h> /* readdir() */
+#include <assert.h>
 #include <sys/time.h>
 #include <sys/time.h>
+
 #include "para.h"
 #include "ipc.h"
 #include "fd.h"
 #include "para.h"
 #include "ipc.h"
 #include "fd.h"
@@ -65,7 +68,7 @@ static void sched_post_select(struct sched *s)
  *
  * \sa task, now.
  */
  *
  * \sa task, now.
  */
-int sched(struct sched *s)
+int schedule(struct sched *s)
 {
        if (!initialized)
                return -E_NOT_INITIALIZED;
 {
        if (!initialized)
                return -E_NOT_INITIALIZED;
@@ -145,7 +148,7 @@ void unregister_task(struct task *t)
 /**
  * unregister all tasks
  *
 /**
  * unregister all tasks
  *
* This will cause \a sched() to return immediately because both the
  * \a pre_select_list and the \a post_select_list are empty.
  */
 void sched_shutdown(void)
@@ -145,7 +148,7 @@ void unregister_task(struct task *t)
  * unregister all tasks
  *
- * This will cause \a sched() to return immediately because both the
+ * This will cause \a schedule() to return immediately because both the
  * \a pre_select_list and the \a post_select_list are empty.
  */
  * \a pre_select_list and the \a post_select_list are empty.
  */
 void sched_shutdown(void)